"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var createMemoryDriver = function createMemoryDriver(storage) {
  var getItem = function getItem(storeName, key) {
    var store = storage[storeName];
    var value = store ? store[key] : undefined;

    return Promise.resolve(value);
  };

  var setItem = function setItem(storeName, key, value) {
    if (!storage[storeName]) {
      storage[storeName] = {};
    }
    var store = storage[storeName];
    store[key] = value;

    return Promise.resolve(value);
  };

  var clear = function clear(storeName) {
    storage[storeName] = {};

    Promise.resolve();
  };

  var close = function close() {
    return Promise.resolve();
  };

  var getCollection = function getCollection(storeName) {
    var store = storage[storeName] || {};

    return Object.keys(store).map(function (key) {
      return store[key];
    });
  };

  var removeItem = function removeItem(storeName, key) {
    delete storage[storeName][key];
  };

  var length = function length(storeName) {
    return Object.keys(storage[storeName]).length;
  };

  var keys = function keys(storeName) {
    return Object.keys(storage[storeName]);
  };

  var iterate = function iterate(storeName, callback) {
    var store = storage[storeName];
    return Object.keys(store).map(function (key) {
      return callback(key, store[key]);
    });
  };

  var destroy = function destroy() {
    storage = {};

    return true;
  };

  return {
    getItem: getItem,
    setItem: setItem,
    clear: clear,
    close: close,
    getCollection: getCollection,
    removeItem: removeItem,
    length: length,
    keys: keys,
    iterate: iterate,
    destroy: destroy
  };
};

exports.default = createMemoryDriver;